==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImageGaussianSource.java <==
// java wrapper for vtkImageGaussianSource object
//

package vtk;
import vtk.*;

public class vtkImageGaussianSource extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetCenter_3(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_3(id0,id1,id2); }

  private native void SetCenter_4(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_4(id0); }

  private native double[] GetCenter_5();
  public double[] GetCenter()
    { return GetCenter_5(); }

  private native void SetMaximum_6(double id0);
  public void SetMaximum(double id0)
    { SetMaximum_6(id0); }

  private native double GetMaximum_7();
  public double GetMaximum()
    { return GetMaximum_7(); }

  private native void SetStandardDeviation_8(double id0);
  public void SetStandardDeviation(double id0)
    { SetStandardDeviation_8(id0); }

  private native double GetStandardDeviation_9();
  public double GetStandardDeviation()
    { return GetStandardDeviation_9(); }

  public vtkImageGaussianSource() { super(); }

  public vtkImageGaussianSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-1-aarch64.pkg.tar.xz: vtk/vtkImageGaussianSource.java <==
// java wrapper for vtkImageGaussianSource object
//

package vtk;
import vtk.*;

public class vtkImageGaussianSource extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetCenter_3(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_3(id0,id1,id2); }

  private native void SetCenter_4(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_4(id0); }

  private native double[] GetCenter_5();
  public double[] GetCenter()
    { return GetCenter_5(); }

  private native void SetMaximum_6(double id0);
  public void SetMaximum(double id0)
    { SetMaximum_6(id0); }

  private native double GetMaximum_7();
  public double GetMaximum()
    { return GetMaximum_7(); }

  private native void SetStandardDeviation_8(double id0);
  public void SetStandardDeviation(double id0)
    { SetStandardDeviation_8(id0); }

  private native double GetStandardDeviation_9();
  public double GetStandardDeviation()
    { return GetStandardDeviation_9(); }

  public vtkImageGaussianSource() { super(); }

  public vtkImageGaussianSource(long id) { super(id); }
  public native long   VTKInit();

}
